﻿using System.ComponentModel;
using System.ComponentModel.Composition;
using System.Windows.Media;

namespace MefImage
{
    [Export]
    public class MainPageViewModel : INotifyPropertyChanged
    {
        public MainPageViewModel()
        {
            ImageScale = 1;
        }

        private string _imageSource;
        [Import("MefImage.ImageSource")]
        public string ImageSource
        {
            get { return _imageSource; }
            set
            {
                _imageSource = value;
                RaisePropertyChanged("ImageSource");
            }
        }

        private string _watermark;
        [Import("MefImage.Watermark")]
        public string Watermark
        {
            get { return _watermark; }
            set { _watermark = value; 
            RaisePropertyChanged("Watermark");
            }
        }

        private double _imageScale;
        public double ImageScale
        {
            get { return _imageScale; }
            set
            {
                _imageScale = value;
                UpdateTransform();
            }
        }

        private double _imageRotate;
        public double ImageRotate
        {
            get { return _imageRotate; }
            set
            {
                _imageRotate = value;
                UpdateTransform();
            }
        }

        public TransformGroup ImageTransform { get; set; }

        public void UpdateTransform()
        {
            ImageTransform = new TransformGroup()
            {
                Children = new TransformCollection()
                {
                    new ScaleTransform { ScaleX = ImageScale, ScaleY = ImageScale },
                    new RotateTransform { Angle = ImageRotate }
                }
            };
            RaisePropertyChanged("ImageTransform");
        }
        #region INotifyPropertyChanged Members

        public event PropertyChangedEventHandler PropertyChanged;
        void RaisePropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        } 
        
        #endregion
    }
}
