﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Net;
using System.Reflection;
using System.Resources;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Ink;
using System.Windows.Input;
using System.Windows.Markup;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;

namespace MefShapes
{
    public static class ApplicationExtensions
    {
        public static List<string> _loadedDictionaries = new List<string>();

        public static void LoadDictionary(this Application application, Assembly assembly, string resource)
        {
            resource = resource.ToLower();
            var name = GetAssemblyNameFromFullName(assembly.FullName);

            if (_loadedDictionaries.Contains(name + "." + resource))
                return;

            var manager = new ResourceManager(name + ".g", assembly);
            var stream = manager.GetStream(resource);
            if (stream == null)
                throw new Exception("Unable to load " + resource);

            string xaml = null;
            using (var sr = new StreamReader(stream))
            {
                xaml = sr.ReadToEnd();
            }

            var dictionary = XamlReader.Load(xaml) as ResourceDictionary;

            if (dictionary == null)
            {
                throw new Exception("Unable to parse " + resource);
            }

            Application.Current.Resources.MergedDictionaries.Add(dictionary);

            _loadedDictionaries.Add(name + "." + resource);
        }

        private static string GetAssemblyNameFromFullName(string fullName)
        {
            var pos = fullName.IndexOf(",");
            if (pos > 0)
            {
                return fullName.Remove(pos);
            }
            return fullName;
        }
    }
}
