using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel.Composition;
using System.Linq;
using MefShapes;

namespace MefShapesViewer
{
    [Export]
    public class MainPageViewModel
    {
        public MainPageViewModel()
        {
            _shapes = new ObservableCollection<IShape>();
            _menuItems = new ObservableCollection<IMenuItem>();

            _menuItems.Add(new MenuItem
            {
                Title = "Reload Shapes",
                Command = new DelegateCommand<string>(ResetShapes)
            });
        }

        private ObservableCollection<IMenuItem> _menuItems;
        [ImportMany(AllowRecomposition=true)]
        public IEnumerable<IMenuItem> MenuItems
        {
            get { return _menuItems; }
            set
            {
                foreach (var m in value)
                {
                    if (!_menuItems.Contains(m))
                    {
                        _menuItems.Add(m);
                    }
                }
            }
        }

        private ObservableCollection<IShape> _shapes;
        [ImportMany(AllowRecomposition=true)]
        public IEnumerable<IShape> Shapes
        {
            get { return _shapes; }
            set
            {
                foreach(var s in value)
                {
                    if (!_shapes.Contains(s))
                    {
                        _shapes.Add(s);
                    }
                }
            }
        }

        void ResetShapes(string parameter)
        {
            var shapes = _shapes.ToList();
            _shapes.Clear();
            Shapes = shapes;
        }
    }
}